summaryrefslogtreecommitdiff
path: root/board/vell/fw_config.c
diff options
context:
space:
mode:
Diffstat (limited to 'board/vell/fw_config.c')
-rw-r--r--board/vell/fw_config.c36
1 files changed, 4 insertions, 32 deletions
diff --git a/board/vell/fw_config.c b/board/vell/fw_config.c
index bf5e29fe05..137c5c9f9a 100644
--- a/board/vell/fw_config.c
+++ b/board/vell/fw_config.c
@@ -12,20 +12,17 @@
#define CPRINTS(format, args...) cprints(CC_CHIPSET, format, ##args)
-static union brya_cbi_fw_config fw_config;
+static union vell_cbi_fw_config fw_config;
BUILD_ASSERT(sizeof(fw_config) == sizeof(uint32_t));
/*
* FW_CONFIG defaults for brya if the CBI.FW_CONFIG data is not
* initialized.
*/
-static const union brya_cbi_fw_config fw_config_defaults = {
- .usb_db = DB_USB3_PS8815,
- .kb_bl = KEYBOARD_BACKLIGHT_ENABLED,
-};
+static const union vell_cbi_fw_config fw_config_defaults = {};
/****************************************************************************
- * Brya FW_CONFIG access
+ * Vell FW_CONFIG access
*/
void board_init_fw_config(void)
{
@@ -33,29 +30,4 @@ void board_init_fw_config(void)
CPRINTS("CBI: Read FW_CONFIG failed, using board defaults");
fw_config = fw_config_defaults;
}
-
- if (get_board_id() == 0) {
- /*
- * Early boards have a zero'd out FW_CONFIG, so replace
- * it with a sensible default value. If DB_USB_ABSENT2
- * was used as an alternate encoding of DB_USB_ABSENT to
- * avoid the zero check, then fix it.
- */
- if (fw_config.raw_value == 0) {
- CPRINTS("CBI: FW_CONFIG is zero, using board defaults");
- fw_config = fw_config_defaults;
- } else if (fw_config.usb_db == DB_USB_ABSENT2) {
- fw_config.usb_db = DB_USB_ABSENT;
- }
- }
-}
-
-union brya_cbi_fw_config get_fw_config(void)
-{
- return fw_config;
-}
-
-enum ec_cfg_usb_db_type ec_cfg_usb_db_type(void)
-{
- return fw_config.usb_db;
}
@@ -12,20 +12,17 @@
BUILD_ASSERT(sizeof(fw_config) == sizeof(uint32_t));
/*
- * FW_CONFIG defaults for brya if the CBI.FW_CONFIG data is not
+ * FW_CONFIG defaults for vell if the CBI.FW_CONFIG data is not
* initialized.
*/